@@ -1,6 +1,18 @@
 import math
 
 
+def bounded_angle_diff(theta_from: float, theta_too: float) -> float:
+    """
+    Finds the bounded (from -π to π) angle difference between two unbounded angles
+    """
+    res = math.fmod(theta_too - theta_from, 6.283185307179586)
+    if res > math.pi:
+        res -= 6.283185307179586
+    if res < -math.pi:
+        res += 6.283185307179586
+    return res
+
+
 def rotate_vector(x: float, y: float, theta: float) -> tuple[float, float]:
     return (
         x * math.cos(theta) - y * math.sin(theta),
